@@ -1,4 +1,4 @@
-use anyhow::*;
+use anyhow::Result;
 use data_rw::{Data, DataReader};
 
 
@@ -6,6 +6,10 @@ use data_rw::{Data, DataReader};
 fn test_resize()->Result<()>{
     let mut data=Data::with_capacity(128);
     data.write_fixed(include_str!("./test.txt"));
+
+    let mut rd=DataReader::from(&data);
+    let r= rd.read_fixed_str()?;
+    assert_eq!(r,include_str!("./test.txt"));
     Ok(())
 }
 
